emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/eev 9a24536: Rewrote many comments.


From: ELPA Syncer
Subject: [elpa] externals/eev 9a24536: Rewrote many comments.
Date: Mon, 25 Oct 2021 23:57:15 -0400 (EDT)

branch: externals/eev
commit 9a24536f7351d406b1b3f59504fc6a568344bf4d
Author: Eduardo Ochs <eduardoochs@gmail.com>
Commit: Eduardo Ochs <eduardoochs@gmail.com>

    Rewrote many comments.
---
 ChangeLog       |  8 +++++
 VERSION         |  4 +--
 eepitch.el      |  6 ++--
 eev-beginner.el | 99 +++++++++++++++++++++++++++++++++++++++++++++------------
 eev-hydras.el   | 12 ++++---
 eev-intro.el    |  5 ---
 eev-load.el     |  9 ++++--
 eev-readme.el   | 11 ++++---
 8 files changed, 112 insertions(+), 42 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 69cc46b..443655c 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,13 @@
+2021-10-25  Eduardo Ochs  <eduardoochs@gmail.com>
+
+       * eev-beginner.el: change the `(add-to-list 'load-path
+       default-directory)' to a better hack.
+
 2021-10-24  Eduardo Ochs  <eduardoochs@gmail.com>
 
+       * eepitch.el (eepitch-ruby, eepitch-irb): irb doesn't work in
+       comint buffers, so use `eepitch-ansiterm'.
+
        * eev-rcirc.el (find-libera-2a): use `find-rcirc-buffer-2a'.
        (find-libera-3a): use `find-rcirc-buffer-3a'.
        (find-freenode-2a): use `find-rcirc-buffer-2a'.
diff --git a/VERSION b/VERSION
index 807ef86..f2318bf 100644
--- a/VERSION
+++ b/VERSION
@@ -1,2 +1,2 @@
-Sun Oct 24 11:58:56 GMT 2021
-Sun Oct 24 08:58:56 -03 2021
+Tue Oct 26 03:23:12 GMT 2021
+Tue Oct 26 00:23:12 -03 2021
diff --git a/eepitch.el b/eepitch.el
index b5f8cc3..43467a0 100644
--- a/eepitch.el
+++ b/eepitch.el
@@ -19,7 +19,7 @@
 ;;
 ;; Author:     Eduardo Ochs <eduardoochs@gmail.com>
 ;; Maintainer: Eduardo Ochs <eduardoochs@gmail.com>
-;; Version:    20211019
+;; Version:    20211024
 ;; Keywords:   e-scripts
 ;;
 ;; Latest version: <http://angg.twu.net/eev-current/eepitch.el>
@@ -931,9 +931,9 @@ The arguments are explained here:
 (defun eepitch-python2 () (interactive) (eepitch-comint "python2" "python2"))
 (defun eepitch-python3 () (interactive) (eepitch-comint "python3" "python3"))
 (defun eepitch-python  () (interactive) (eepitch-comint "python3" "python3"))
-(defun eepitch-ruby   () (interactive) (eepitch-comint "ruby"   "irb"))
-(defun eepitch-ruby   () (interactive) (eepitch-comint "ruby"   "irb 
--simple-prompt"))
 (defun eepitch-perl () (interactive) (eepitch-comint "perl" "perl -d -e 42"))
+(defun eepitch-ruby    () (interactive) (eepitch-ansiterm "irb" "irb"))
+(defun eepitch-irb     () (interactive) (eepitch-ansiterm "irb" "irb"))
 
 ;; Tcl:
 (defun eepitch-tcl     () (interactive) (eepitch-comint "tclsh"   "tclsh"))
diff --git a/eev-hydras.el b/eev-hydras.el
index 32b080d..4d7698c 100644
--- a/eev-hydras.el
+++ b/eev-hydras.el
@@ -19,7 +19,7 @@
 ;;
 ;; Author:     Eduardo Ochs <eduardoochs@gmail.com>
 ;; Maintainer: Eduardo Ochs <eduardoochs@gmail.com>
-;; Version:    20210521
+;; Version:    20211025
 ;; Keywords:   e-scripts
 ;;
 ;; Latest version: <http://angg.twu.net/eev-current/eev-hydras.el>
@@ -38,8 +38,12 @@
 ;;   (find-refining-intro "5. Pointing to anchors")
 ;;   (find-refining-intro "5. Pointing to anchors" "but I don't touch-type")
 ;;
-;; It depends on the package "hydra".
-;; I need to record a short video about this.
+;; It depends on the package "hydra" (from ELPA).
+;; To learn how this works, load this file and run this tutorial - i.e.:
+;;
+;;   (require 'eev-hydras)
+;;   (find-eev-index-edit-intro)
+;;
 ;; This code will probably change a LOT in the next months.
 ;; Update: I recorded a video, it's here:
 ;;
@@ -128,7 +132,7 @@ It is meant as both a tutorial and a sandbox.
 
 
 
-This is \"intro\" is a sandboxed tutorial for:
+This \"intro\" is a sandboxed tutorial for:
 
   (find-eev \"eev-hydras.el\")
   (find-refining-intro \"5. Pointing to anchors\")
diff --git a/eev-intro.el b/eev-intro.el
index 6c62a1e..ccdb8d3 100644
--- a/eev-intro.el
+++ b/eev-intro.el
@@ -437,11 +437,6 @@ or the elisp source files, installed. The names for the 
packages which
 have those things vary from one GNU/Linux distro to another. On Debian
 something like
 
-  sudo apt-get install emacs24-el
-  sudo apt-get install emacs24-common-non-dfsg
-
-or
-
   sudo apt-get install emacs-el
   sudo apt-get install emacs-common-non-dfsg
 
diff --git a/eev-load.el b/eev-load.el
index 9648e1a..83af9f3 100644
--- a/eev-load.el
+++ b/eev-load.el
@@ -1,7 +1,7 @@
 ;;; eev-load.el -- load all the main modules of eev.  -*- lexical-binding: 
nil; -*-
 ;;; This can also be used as an index to the main source files.
 
-;; Copyright (C) 2019-2020 Free Software Foundation, Inc.
+;; Copyright (C) 2019-2021 Free Software Foundation, Inc.
 ;;
 ;; This file is part of GNU eev.
 ;;
@@ -20,7 +20,7 @@
 ;;
 ;; Author:     Eduardo Ochs <eduardoochs@gmail.com>
 ;; Maintainer: Eduardo Ochs <eduardoochs@gmail.com>
-;; Version:    20190929
+;; Version:    20211024
 ;; Keywords:   e-scripts
 ;;
 ;; Supersedes: (find-eev "eev-all.el")
@@ -161,6 +161,11 @@
 ;; Note the "'" at the beginning of each line!
 
 
+;; Make `M-x eev-beginner' work in the "expert setups" too.
+;; See: (find-efunctiondescr 'autoload "If FUNCTION is already defined")
+(autoload 'eev-beginner "eev-beginner") ; (find-eev "eev-beginner.el")
+
+
 
 (provide 'eev-load)
 
diff --git a/eev-readme.el b/eev-readme.el
index 04efc36..abd64f9 100644
--- a/eev-readme.el
+++ b/eev-readme.el
@@ -19,7 +19,7 @@
 ;;
 ;; Author:     Eduardo Ochs <eduardoochs@gmail.com>
 ;; Maintainer: Eduardo Ochs <eduardoochs@gmail.com>
-;; Version:    20190302
+;; Version:    20211025
 ;; Keywords:   e-scripts
 ;;
 ;; Latest version: <http://angg.twu.net/eev-current/eev-readme.el>
@@ -32,15 +32,16 @@
 
 ;;; Commentary:
 
-;; See this for the current standard ways to install eev:
+;; Until march/2019 this file was used by a few of the (many) ways of
+;; loading eev; now it is totally obsolete, and it will be removed at
+;; some point. See these for the current standard ways to install eev:
 ;;   
+;;   (find-eev "eev-beginner.el")
+;;   (find-eev "eev-load.el")
 ;;   (find-eev-quick-intro "1. Installing eev")
 ;;   (find-eev-install-intro)
 ;;
 ;; The rest of this file is very old.
-;; This file has been superseded by:
-;;
-;;   (find-eev "eev-beginner.el")
 
 ;; Quick instructions:
 ;;



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/eev-beginner.el b/eev-beginner.el
index 6f6ecdb..08ae9e9 100644
--- a/eev-beginner.el
+++ b/eev-beginner.el
@@ -27,11 +27,21 @@
 ;;                 <http://angg.twu.net/eev-intros/find-eev-quick-intro.html>
 ;;                                                (find-eev-quick-intro)
 
+;; «.load-path-hack»   (to "load-path-hack")
+
+
 ;;; Commentary:
 
+;; 1. Eev for beginners
+;; ====================
 ;; This file loads all modules of eev, turns eev-mode on, and opens
 ;; the main tutorial - i.e., runs `(find-eev-quick-intro)'. It is used
 ;; by the two most common ways of installing eev:
 ;;
 ;; 1) If you install eev as an emacs package via `M-x list-packages'
 ;;    then no eev modules will be loaded UNTIL you run `M-x
@@ -43,9 +53,14 @@
 ;;      (find-eev-intro "1. `eev-mode'")
 ;;      (find-eev-intro "1. `eev-mode'" "If you load eev")
 ;;
+;;    If you use one of the non-standard package managers for Emacs,
+;;    like use-package or straight.el, then read this:
+;;
+;;      (find-eev-install-intro "5.5. `use-package'")
+;;
 ;; 2) Some people start playing with Emacs+eev by copying and pasting
 ;;    a certain script to a shell in a terminal and executing it,
-;;    following the instructions here:
+;;    following the instructions in the third sexp below:
 ;;
 ;;      (find-eev-quick-intro "1. Installing eev")
 ;;      (find-eev-quick-intro "1. Installing eev" "tarball")
@@ -62,6 +77,24 @@
 ;;    Emacs evaluate the sexp `(find-eev-quick-intro)', that opens the
 ;;    main tutorial.
 ;;
+;;
+;; 2. Eev for non-beginners
+;; ========================
+;; This file:
+;;
+;;   a. loads all modules of eev,
+;;   b. turns eev-mode on, and
+;;   c. opens the main tutorial.
+;;
+;; If you want to do just (a), or not even (a) but you want to be
+;; able to run `M-x eev-beginner' and `M-x eev-mode', then read:
+;;
+;;   (find-eev "eev-load.el")
+;;   (find-eev-quick-intro "1. Installing eev")
+;;
+;;
+;; 3. Rationale
+;; ============
 ;; The idea is that even after installing eev:
 ;;
 ;; 1) it should be trivial to try eev in "beginner mode",
@@ -71,41 +104,65 @@
 ;;
 ;;      (find-enode "Lisp Libraries" "autoloaded")
 ;;
-;; Some people are very finicky about packages that make global
-;; changes when loaded. Loading all modules of eev causes the (almost
-;; insignificant?) global changes described here,
+;; My reason for caring about (2) is that some people are very finicky
+;; about packages that make global changes when loaded. Loading all
+;; modules of eev causes the (almost insignificant?) global changes
+;; described here,
 ;;
 ;;   (find-eev-intro "1. " "the only" "things that happen")
 ;;
 ;; that aren't reverted by deactivating eev-mode with `M-x eev-mode',
-;; and eev defines some functions with the prefix `find-', as
+;; _AND_ eev defines some functions with the prefix `find-', as
 ;; explained here:
 ;;
 ;;   (find-eev-intro "4. The prefix `find-'")
+;;   (find-eev-intro "4. The prefix `find-'" "list all")
 ;;
+;; Some people consider that these `find-' functions from eev sort of
+;; "invade the global namespace", and they want to be able to run
+;; Emacs without them, and load eev only when they want or need to.
 ;; I've tried to make eev friendly to several kinds of people,
-;; including total beginners and very finicky old-timers, and this
-;; file - "eev-beginner.el" - seems to provide a good solution.
-;;
-;; The instructions for making Emacs load eev at startup are here:
+;; including total beginners and these very finicky old-timers, and
+;; this file - "eev-beginner.el" - seems to provide a good solution.
+;; The finicky old-timers just need to use one of the "expert setups":
 ;;
 ;;   (find-eev-install-intro "2. The expert setup")
+;;   (find-eev "eev-load.el")
 
 
-;; NOTE: older versions of eev loaded "eev-readme.el" instead of
-;; "eev-beginner.el". Compare:
-;;
-;;   (find-eev "eev-readme.el")
-;;   (find-eev "eev-load.el")
 
 
+;; «load-path-hack»  (to ".load-path-hack")
+;;
+;; This is a hack to make eev easier to use by beginners that don't
+;; understand the load-path yet. If they run something that runs:
+;;
+;;   (load "/path/to/eev-beginner.el")
+;;
+;; this hack puts the "/path/to/" in the load-path, and if they try
+;; to load this file with
+;;
+;;   (eval-buffer)
+;;
+;; this hack puts the default-directory in the load-path.
+;;
+;; See: (find-elnode "How Programs Do Loading")
+;;      (find-enode "Variable Index" "* load-path:")
+;;      (find-elnode         "Index" "* load-path:")
+;;      (find-eppp                      load-path)
+;;      (find-efunctiondescr 'load)
+;;      (find-efunctiondescr 'load "load-in-progress")
+;;      (find-efunctiondescr 'load "load-file-name")
+;;      (find-evardescr            'load-file-name)
+;;
+(add-to-list 'load-path
+            (if load-in-progress
+                (file-name-directory load-file-name)
+              default-directory))
 
-;; 2019mar13: Commented this out.
-;; 2019mar29: Uncommented - it seems that emacs25 needs this.
-(add-to-list 'load-path default-directory)
 
-;; Load all the main modules of eev.
-;; Do not load some advanced modules that require extra setup.
+;; This require loads all the main modules of eev.
+;; It doesn't load some advanced modules that require extra setup.
 ;; See the comments here: (find-eev "eev-load.el")
 (require 'eev-load)
 
@@ -27,11 +27,21 @@
 ;; This file loads all modules of eev, turns eev-mode on, and opens
-;; the main tutorial - i.e., runs `(find-eev-quick-intro)'. It is used
-;; by the two most common ways of installing eev:
+;; the main tutorial - this one:
+;;
+;;   (find-eev-quick-intro)
+;;
+;; This file is used by the two most common ways of installing eev
+;; "for beginners", described below. The ways of loading eev without
+;; opening the tutorial are described in the next section.
 ;;
 ;; 1) If you install eev as an emacs package via `M-x list-packages'